/***************************************************************************
*** Name: 						I2C-Display 																			
*** Function: 			    	I2C Display Driver (8 x 16-Segments)						   */
/** \defgroup 					i2cdisplay I2C-LCD-Display																		
*** \brief 						Routines to run a I2C-Display (Type DSM-0822a)									
***	\author             	Andreas Hesse andreas@andi-hesse.de  http://www.andi-hesse.de
*** @dat							Date of construction: 		2004-02-14
*** @date 						Date of last revision: 	2004-02-25
*** \version 						1.1
***	\todo						enter bool definitions
***	\todo						something more 
***	\test						Equipment is the Phase 2 hardware with a at90s2313
***	\bug						no bugs found
*** @note 
*** The DSM0822a Display has 8 Characters (each 16 segments) and 16 special signs (used normally for audio applications). 
		This source is based on assembler sources, and help from the internet. 
		Thanks to all! 
******************************************************************************
***
*** - + = Adding new feature
*** - - = Bugfix
*** - * = Changed
*** - ? = detected problem
***
******************************************************************************
***
*** Version management:
*** - V 1.1  Added doxygen information
*** - V 1.1  First construction based on several assembler sources 
*** */


// ***	@code #include <i2cdisp.h> @endcode
// Use "-" in front of all to create a HTML-List!!!
/*@{*/

#include <avr/pgmspace.h>
#ifndef __I2CD_INCLUDED
#define __I2CD_INCLUDED

/** 
 @brief adress of DSM0822a display (fixed DSM0822a=112, see datasheet)
*/																
#define DSM0822a  				0x70   

/** 
 @brief DSM0822a has 8 characters
 */
#define _No_of_characters 	8 
																	// Display has 8 Characters

 // Global constants
 
 /** 
 @brief structure to hold 16-segment-definitions
 */
 
 typedef struct TCharDef
 {
	unsigned char byte1;
	unsigned char byte2;
 } TCharDef;

 /** 
 @brief Gets a character definition  
 @param ASCII Character No. (only uppercase is allowed!)
 @return 2 Byte definition for 16-Segment display
 */

TCharDef	GetCharDef(int ChrNo);
 
  /** 
 @brief Write a message to the display 
 @param Message
 @return void
 */

void Write_To_I2CDisplay (char Message[_No_of_characters]);

 
  /** 
 @brief Write relevant data to the display
 @param -
				 - blink: Display blinks (see datasheet of PCF...)
				 - specsign1,specsign2: activate special signs of display (like FM, RDS...)
				 - Message to display
 @return Integer, which is 0 if successful startcondition of I2C and !=0 if not
 */

int I2CDisplay (unsigned char blink, unsigned char specsign1, unsigned char specsign2, char Message[_No_of_characters]);




 /*@}*/   
 // Important comments for doxygen
 #endif

